/**
 * 音频懒加载
 * @param {Object}   obj       DOMElement
 * @param {Function} callback  加载完成回调函数
 */
function lazyloadAudio(obj, callback){
    var debug = false; // 默认打印调试日志
    if(obj.getAttribute('data-loaded')){
       return; 
    }

    var audio_url = obj.getAttribute('data-lazyload');  
    debug && console.log(audio_url);

	var fileNames = audio_url.split("/");
	debug && console.log("文件名:"+fileNames[fileNames.length-1]); 
	 
	var fileId = fileNames[fileNames.length-1].split(".")[0];
	debug && console.log("fileId:"+fileId); 

    // 1. 转换网络音频地址为本地缓存音频路径，判断该图片是否存在本地缓存
    var local_audio_url     = audio_url; // 缓存本地音频url
//  var audio_url           = WEB_URL() + audio_url;
	var audio_url           = WEB_URL() + "zsconfig/downloadFile?fileId=" + fileId;
    var absolute_audio_path = plus.io.convertLocalFileSystemURL(local_audio_url); // 平台绝对路径


    // new temp_img 用于判断音频文件是否存在
    var temp_audio = new Audio();
    temp_audio.src = absolute_audio_path;
    temp_audio.onload = function(){
        debug && console.log('存在本地缓存音频文件'+local_audio_url+'，直接显示');

        // 1.1 存在，则直接显示（本地已缓存，不需要淡入动画）
        obj.setAttribute('src', absolute_audio_path);
        obj.setAttribute('data-loaded', true);
        obj.classList.add('img-lazyload');

        callback && callback();
        return;
    }
    temp_audio.onerror = function(){
        debug && console.log('不存在本地缓存音频文件');
		obj.removeAttribute('data-lazyload');
        // 1.2 下载图片缓存到本地
        debug && console.log('开始下载音频'+audio_url+' 缓存到本地: '+local_audio_url);
        function download_audio(){
            var download_task = plus.downloader.createDownload(audio_url, {
                filename: local_audio_url // filename:下载任务在本地保存的文件路径
            }, function(download, status) {
                if(status != 200){
                	obj.setAttribute('data-lazyload',audio_url);
                    // 下载失败,删除本地临时文件
                    debug && console.log('下载失败,status'+status);
                    if(local_audio_url != null){
                        plus.io.resolveLocalFileSystemURL(local_audio_url, function(entry) {
                            entry.remove(function(entry) {
                                debug && console.log("临时文件删除成功" + local_audio_url);
                                // 重新下载图片
                                download_audio();
                            }, function(e) {
                                debug && console.log("临时文件删除失败" + local_audio_url);
                            });
                        });
                    }
                }else{
                    // 把下载成功的图片显示
                    // 将本地URL路径转换成平台绝对路径
                    obj.setAttribute('src', plus.io.convertLocalFileSystemURL(local_audio_url));
                    obj.setAttribute('data-loaded', true);
                    obj.classList.add('img-lazyload');

                    callback && callback();
                }
            });
            download_task.start();
        }
        download_audio();
    }

}