(function($, window, document) {
	var ImageLazyload = $.Lazyload.extend({
		init: function(element, options) {
			this._super(element, options);
		},
		_init: function() {
			this.options.selector = '[data-lazyload]';
			this._super();
		},
		_set: function(element, uri) {
			if (element.tagName === 'IMG') {
				element.src = uri;
			} else {
				element.style.backgroundImage = "url(" + uri + ")";
			}
		},
		_hasPlaceholder: function(element) {
			if (element.offsetWidth) {
				if (element.tagName === 'IMG') {
					return !!element.src;
				} else {
					return !!element.style.backgroundImage;
				}
			}
			return false;
		},
		_addPlaceHolder: function(element) {
			var self = this;
			if (element.tagName === 'IMG') {
				self._counter++;
				element.onload = function() {
					self._counter--;
					self.addCallback(element, self.handle);
					this.onload = null;
				};
				self.onPlaceHolder(function(placeholder) {
					self._set(element, placeholder);
				});
			} else {
				element.style.backgroundImage = "url(" + self.options.placeholder + ")";
			}
		},
		addElement: function(element) {
			var self = this;
			var uri = element.getAttribute('data-lazyload');
			if (uri) {
				if (self._hasPlaceholder(element)) {
					self.addCallback(element, self.handle);
				} else {
					self.onPlaceHolder = self._createLoader(function(callback) {
						var img = new Image();
						var placeholder = self.options.placeholder;
						img.src = placeholder;
						img.onload = img.onerror = function() {
							callback(placeholder);
						};
					});
					self._addPlaceHolder(element);
				}
				return true;
			}
			return false;
		},
		set: function(element, uri) {
			var self = this;
			var img = new Image();
			img.onload = function() {
				self._set(element, uri);
				$.trigger(self.element, 'success', {
					element: element,
					uri: uri
				});
			};
			img.onerror = function() {
				$.trigger(self.element, 'error', {
					element: element,
					uri: uri
				});
			};
			img.src = uri;
			element.removeAttribute('data-lazyload'); //只尝试一次，后续可能支持多次尝试
		},
		handle: function(element, key) {
			var uri = element.getAttribute('data-lazyload');
			if (uri) {
				lazyloadNew(element);
				this.set(element, uri);
				//element.parentNode.parentNode.setAttribute('data-lazyload', 'true'); //debug
			}
		},
		destroy: function() {
			this._super();
			this.element.removeAttribute('data-imageLazyload');
		}

	});
	$.fn.imageLazyload = function(options) {
		var lazyloadApis = [];
		this.each(function() {
			var self = this;
			var lazyloadApi = null;
			if (self === document || self === window) {
				self = document.body;
			}
			lazyloadNew(this);
			var id = self.getAttribute('data-imageLazyload');
			if (!id) {
				id = ++$.uuid;
				$.data[id] = lazyloadApi = new ImageLazyload(self, options);
				self.setAttribute('data-imageLazyload', id);
			} else {
				lazyloadApi = $.data[id];
			}
			lazyloadApis.push(lazyloadApi);
		});
		return lazyloadApis.length === 1 ? lazyloadApis[0] : lazyloadApis;
	}
})(mui, window, document);



/**
 * 图片懒加载
 * @param {Object}   obj       DOMElement
 * @param {Function} callback  加载完成回调函数
 */
function lazyloadNew(obj, callback){
    var debug = false; // 默认打印调试日志 
    if(obj.getAttribute('data-loaded')){
       return; 
    }

    var image_url = obj.getAttribute('data-lazyload'); 
    debug && console.log(image_url); 

	var fileNames = image_url.split("/");
	debug && console.log("文件名:"+fileNames[fileNames.length-1]); 
	 
	var fileId = fileNames[fileNames.length-1].split(".")[0];
	debug && console.log("fileId:"+fileId[0]); 
	
    // 1. 转换网络图片地址为本地缓存图片路径，判断该图片是否存在本地缓存
    var local_image_url     = image_url; // 缓存本地图片url   
    var image_url           = WEB_URL() + "zsconfig/downloadFile?fileId=" + fileId;
    console.log(local_image_url);
    var absolute_image_path = plus.io.convertLocalFileSystemURL(local_image_url); // 平台绝对路径


    // new temp_img 用于判断图片文件是否存在
    var temp_img = new Image();
    temp_img.src = absolute_image_path;
    temp_img.onload = function(){
        debug && console.log('存在本地缓存图片文件'+local_image_url+'，直接显示');

        // 1.1 存在，则直接显示（本地已缓存，不需要淡入动画）
        obj.setAttribute('src', absolute_image_path);
        obj.setAttribute('data-loaded', true);
        obj.classList.add('img-lazyload');

        callback && callback();
        return;
    }
    temp_img.onerror = function(){
        debug && console.log('不存在本地缓存图片文件');
		obj.removeAttribute('data-lazyload');
        // 1.2 下载图片缓存到本地
        debug && console.log('开始下载图片'+image_url+' 缓存到本地: '+local_image_url);
        function download_img(){
            var download_task = plus.downloader.createDownload(image_url, {
                filename: local_image_url, // filename:下载任务在本地保存的文件路径
                retry:1,
                timeout:20
            }, function(download, status) { 
                if(status != 200){ 
                	obj.setAttribute('data-lazyload',image_url);
                    // 下载失败,删除本地临时文件
                    debug && console.log('下载失败,status'+status);
                    if(local_image_url != null){
                        plus.io.resolveLocalFileSystemURL(local_image_url, function(entry) {
                            entry.remove(function(entry) {
                                debug && console.log("临时文件删除成功" + local_image_url);
                                // 重新下载图片
                                download_img();
                            }, function(e) {
                                debug && console.log("临时文件删除失败" + local_image_url);
                            });
                        });
                    }
                }else{
                    // 把下载成功的图片显示
                    // 将本地URL路径转换成平台绝对路径
                    obj.setAttribute('src', plus.io.convertLocalFileSystemURL(local_image_url));
                    obj.setAttribute('data-loaded', true);
                    obj.classList.add('img-lazyload');

                    callback && callback();
                }
            });
            download_task.start();
        }
        download_img();
    }

}